@@ -9,18 +9,20 @@ class JpsClient(BaseClient):
     def __init__(self, api_client: ApiClient):
         super().__init__(api_client)
 
-    def install(self, filename: str, env_name: str) -> str:
+    def install_from_file(self, filename: str, env_name: str) -> str:
         with open(filename) as file:
             manifest_content = file.read()
+            return self.install(manifest_content, env_name)
 
-            response = self._execute(
-                who_am_i(),
-                jps=manifest_content,
-                envName=env_name,
-                skipNodeEmails=True,
-            )
+    def install(self, manifest_content: str, env_name: str) -> str:
+        response = self._execute(
+            who_am_i(),
+            jps=manifest_content,
+            envName=env_name,
+            skipNodeEmails=True,
+        )
 
-            return response["successText"]
+        return response["successText"]
 
     def get_engine_version(self) -> str:
         response = self._execute(
